==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Defaults } from "./Defaults";
import { runOn, enumGetBox, markType, markDep, fromEnum } from "igniteui-react-core";
import { Pool$1 } from "igniteui-react-core";
import { Rectangle } from "igniteui-react-core";
import { ChartSelection } from "./ChartSelection";
import { List$1 } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
var ColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeries, _super);
    function ColumnSeries() {
        var _this = _super.call(this) || this;
        _this.ac6 = null;
        _this.ac1 = 0;
        _this.ab = ColumnSeries.$;
        _this.ack = 2;
        return _this;
    }
    ColumnSeries.prototype.bk = function () {
        return new ColumnSeries();
    };
    ColumnSeries.prototype.get_e1 = function () {
        return true;
    };
    ColumnSeries.prototype.get_fm = function () {
        return true;
    };
    ColumnSeries.prototype.jl = function () {
        if (!isNaN_(this.jk)) {
            return _super.prototype.jl.call(this);
        }
        return Defaults.h;
    };
    ColumnSeries.prototype.ct = function () {
        return new ColumnSeriesView(this);
    };
    ColumnSeries.prototype.q3 = function (a) {
        _super.prototype.q3.call(this, a);
        this.ac0 = a;
    };
    ColumnSeries.prototype.cz = function () {
        if (this.c0 == 0) {
            return 2;
        }
        return _super.prototype.cz.call(this);
    };
    ColumnSeries.prototype.y9 = function () {
        return 1;
    };
    ColumnSeries.prototype.get_ef = function () {
        return true;
    };
    ColumnSeries.prototype.preferredCategoryMode = function (a) {
        return this.ack;
    };
    ColumnSeries.prototype.ws = function (a) {
        if (this.ac6 == null) {
            this.ac6 = runOn(this, this.ac3);
        }
        var b = this.acn != null ? this.acn : this.yAxis;
        var c = this.ach;
        return this.aa4.c$d(this, a, c, b, this.yz, this.z0(this.cw), this.z1(this.cw), this.ac6);
    };
    ColumnSeries.prototype.gx = function (a, b) {
        if (this.g0(a, b)) {
            return true;
        }
        if (this.xm(a, b)) {
            return true;
        }
        return false;
    };
    ColumnSeries.prototype.o7 = function (a, b) {
        _super.prototype.o7.call(this, a, b);
        var c = b;
        if (a && c.du != null) {
            c.du.count = 0;
        }
    };
    ColumnSeries.prototype.ix = function () {
        return this.ach.k8(this.cw.ca, this.cw.b9, this.getEffectiveViewport1(this.cw));
    };
    ColumnSeries.prototype.ak = function (a, b) {
        var c = new List$1(ChartSelection.$, 0);
        this.p6(a, c, b);
        return c.toArray();
    };
    ColumnSeries.prototype.p6 = function (a, b, c) {
        this.aah(a, b, c, this.yy, 1);
    };
    ColumnSeries.prototype.aap = function (a, b) {
        _super.prototype.aap.call(this, a, b);
        var c = a.h;
        if (!b.w()) {
            return;
        }
        var d = b.ca;
        var e = b.b9;
        var f = this.getEffectiveViewport1(b);
        var g = new ScalerParams(0, d, e, this.acn.ch, f);
        g.b = this.iz();
        var h = new ScalerParams(0, d, e, this.ach.ch, f);
        var i = this.acn;
        var j = i.el(i.me, g);
        var k = this.ach.k8(d, e, f);
        var l = this.ach;
        var m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.du.count = 0;
            return;
        }
        this.y7.a2(this, this.zr(), runOn(this, this.yr), this.z0(b), this.z1(b));
        this.y7.r = this.ac4;
        this.y7.s = this.ac5;
        this.y7.k = this.ac4;
        this.y7.l = this.ac5;
        var n = false;
        var o = this.y7.b;
        if (o != null) {
            n = true;
        }
        var p = this.ach.cn;
        var q = p ? this.ach : null;
        var r = this.valueColumn.count;
        var s = this.z0(b);
        var t = 0;
        for (var u = 0; u < c.count; ++u) {
            var v = c._inner[u][0] - 0.5 * k;
            var w = this.ac3(c._inner[u]);
            var x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            var y = Math.abs(x - w);
            if (isInfinity(y) || isNaN_(y)) {
                continue;
            }
            var z = m.du.item(t);
            t++;
            z.width = k;
            z.height = y;
            var aa = this.y7.aw(r, u)[0];
            if (p && a.o != null && u >= 0 && u < a.o.count) {
                aa = truncate(Math.round(a.o._inner[u]));
            }
            if (n) {
                this.aal(c, u, r, l, h, b.t, aa);
            }
            if (z.dataContext != null) {
                var ab = z.dataContext;
                if (s == 1) {
                    if (aa >= 0 && aa < this.dp.count) {
                        if (q != null && q.i$b != null && q.i$b.count > aa) {
                            aa = q.i$b._inner[aa];
                        }
                        ab.item = this.dp.item(aa);
                    }
                }
                else {
                    ab.item = null;
                }
            }
            this.y7.ad(z, false, false, false, false);
            z.ap = this.y7.k;
            z.aq = this.y7.l;
            m.dz(z, v, Math.min(x, w));
        }
        m.du.count = t;
        b.dg(a);
    };
    Object.defineProperty(ColumnSeries.prototype, "ac2", {
        get: function () {
            return this.ac1;
        },
        set: function (a) {
            if (this.ac2 != a) {
                var b = this.ac2;
                this.ac1 = a;
                this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.ac2));
            }
        },
        enumerable: false,
        configurable: true
    });
    ColumnSeries.prototype.ac3 = function (a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.ac2) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                var b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                var c = this.yAxis.eo(b, new ScalerParams(1, this.dc.w0, this.dc.wz, this.yAxis.ch));
                if (c < this.yAxis.me) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                var d = (a[1] + a[2]) / 2;
                var e = this.yAxis.eo(d, new ScalerParams(1, this.dc.w0, this.dc.wz, this.yAxis.ch));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.me) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    };
    Object.defineProperty(ColumnSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zv;
        },
        enumerable: false,
        configurable: true
    });
    ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
    ColumnSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:ac4:ada', [1, 0], 'RadiusY:ac5:adb', [1, 0]]);
    return ColumnSeries;
}(HorizontalAnchoredCategorySeries));
export { ColumnSeries };
/**
 * @hidden
 */
var ColumnSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeriesView, _super);
    function ColumnSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dt = null;
        _this.dv = null;
        _this.d0 = new Rectangle();
        _this.du = null;
        _this.dt = a;
        _this.du = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.d1);
            $ret.activate = runOn(_this, _this.dw);
            $ret.disactivate = runOn(_this, _this.dy);
            $ret.destroy = runOn(_this, _this.dx);
            return $ret;
        })());
        return _this;
    }
    ColumnSeriesView.prototype.a4 = function () {
        _super.prototype.a4.call(this);
        this.dv = new List$1(Rectangle.$, 0);
        if (!this.t) {
            this.dt.jq = Defaults.i;
            this.dt.xf = Defaults.c;
        }
    };
    ColumnSeriesView.prototype.d1 = function () {
        var a = new Rectangle();
        this.dv.add(a);
        a._visibility = 1;
        return a;
    };
    ColumnSeriesView.prototype.dw = function (a) {
        a._visibility = 0;
    };
    ColumnSeriesView.prototype.dy = function (a) {
        a._visibility = 1;
    };
    ColumnSeriesView.prototype.dx = function (a) {
        this.dv.remove(a);
    };
    ColumnSeriesView.prototype.dz = function (a, b, c) {
        if (!this.isDirty) {
            this.a2();
        }
        a.o = c;
        a.n = b;
    };
    ColumnSeriesView.prototype.ak = function (a) {
        return this.dv._inner[a];
    };
    ColumnSeriesView.prototype.aj = function (a) {
        var b = this.dv._inner[a];
        this.d0._visibility = b._visibility;
        this.d0.n = b.n;
        this.d0.o = b.o;
        this.d0.width = b.width;
        this.d0.height = b.height;
        var c = this.b4(a);
        this.d0._fill = c;
        this.d0._stroke = c;
        this.d0.ad = this.f.ig + 3;
        return this.d0;
    };
    ColumnSeriesView.prototype.bj = function (a, b) {
        _super.prototype.bj.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.dv.count; c++) {
                var d = this.ai(c, b);
                this.br(d, c, b);
                a.w(d);
            }
        }
    };
    ColumnSeriesView.prototype.ax = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.ax.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = __values(fromEnum(this.du.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = __values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                this.f.bc.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        b++;
    };
    ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
    return ColumnSeriesView;
}(AnchoredCategorySeriesView));
export { ColumnSeriesView };

==> igniteui-react-charts-19.0.1.tgz: package/esm5/lib/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Defaults } from "./Defaults";
import { runOn, enumGetBox, markType, markDep, fromEnum } from "igniteui-react-core";
import { Pool$1 } from "igniteui-react-core";
import { Rectangle } from "igniteui-react-core";
import { ChartSelection } from "./ChartSelection";
import { List$1 } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
var ColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeries, _super);
    function ColumnSeries() {
        var _this = _super.call(this) || this;
        _this.ac9 = null;
        _this.ac4 = 0;
        _this.ab = ColumnSeries.$;
        _this.acn = 2;
        return _this;
    }
    ColumnSeries.prototype.bk = function () {
        return new ColumnSeries();
    };
    ColumnSeries.prototype.get_e1 = function () {
        return true;
    };
    ColumnSeries.prototype.get_fm = function () {
        return true;
    };
    ColumnSeries.prototype.jl = function () {
        if (!isNaN_(this.jk)) {
            return _super.prototype.jl.call(this);
        }
        return Defaults.h;
    };
    ColumnSeries.prototype.ct = function () {
        return new ColumnSeriesView(this);
    };
    ColumnSeries.prototype.q3 = function (a) {
        _super.prototype.q3.call(this, a);
        this.ac3 = a;
    };
    ColumnSeries.prototype.cz = function () {
        if (this.c0 == 0) {
            return 2;
        }
        return _super.prototype.cz.call(this);
    };
    ColumnSeries.prototype.y9 = function () {
        return 1;
    };
    ColumnSeries.prototype.get_ef = function () {
        return true;
    };
    ColumnSeries.prototype.preferredCategoryMode = function (a) {
        return this.acn;
    };
    ColumnSeries.prototype.ws = function (a) {
        if (this.ac9 == null) {
            this.ac9 = runOn(this, this.ac6);
        }
        var b = this.acq != null ? this.acq : this.yAxis;
        var c = this.ack;
        return this.aa7.c$d(this, a, c, b, this.yz, this.z0(this.cw), this.z1(this.cw), this.ac9);
    };
    ColumnSeries.prototype.gx = function (a, b) {
        if (this.g0(a, b)) {
            return true;
        }
        if (this.xm(a, b)) {
            return true;
        }
        return false;
    };
    ColumnSeries.prototype.o7 = function (a, b) {
        _super.prototype.o7.call(this, a, b);
        var c = b;
        if (a && c.du != null) {
            c.du.count = 0;
        }
    };
    ColumnSeries.prototype.ix = function () {
        return this.ack.k8(this.cw.ca, this.cw.b9, this.getEffectiveViewport1(this.cw));
    };
    ColumnSeries.prototype.ak = function (a, b) {
        var c = new List$1(ChartSelection.$, 0);
        this.p6(a, c, b);
        return c.toArray();
    };
    ColumnSeries.prototype.p6 = function (a, b, c) {
        this.aak(a, b, c, this.yy, 1);
    };
    ColumnSeries.prototype.aas = function (a, b) {
        _super.prototype.aas.call(this, a, b);
        var c = a.h;
        if (!b.w()) {
            return;
        }
        var d = b.ca;
        var e = b.b9;
        var f = this.getEffectiveViewport1(b);
        var g = new ScalerParams(0, d, e, this.acq.ch, f);
        g.b = this.iz();
        var h = new ScalerParams(0, d, e, this.ack.ch, f);
        var i = this.acq;
        var j = i.el(i.me, g);
        var k = this.ack.k8(d, e, f);
        var l = this.ack;
        var m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.du.count = 0;
            return;
        }
        this.y7.a2(this, this.zr(), runOn(this, this.yr), this.z0(b), this.z1(b));
        this.y7.r = this.ac7;
        this.y7.s = this.ac8;
        this.y7.k = this.ac7;
        this.y7.l = this.ac8;
        var n = false;
        var o = this.y7.b;
        if (o != null) {
            n = true;
        }
        var p = this.ack.cn;
        var q = p ? this.ack : null;
        var r = this.valueColumn.count;
        var s = this.z0(b);
        var t = 0;
        for (var u = 0; u < c.count; ++u) {
            var v = c._inner[u][0] - 0.5 * k;
            var w = this.ac6(c._inner[u]);
            var x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            var y = Math.abs(x - w);
            if (isInfinity(y) || isNaN_(y)) {
                continue;
            }
            var z = m.du.item(t);
            t++;
            z.width = k;
            z.height = y;
            var aa = this.y7.aw(r, u)[0];
            if (p && a.o != null && u >= 0 && u < a.o.count) {
                aa = truncate(Math.round(a.o._inner[u]));
            }
            if (n) {
                this.aao(c, u, r, l, h, b.t, aa);
            }
            if (z.dataContext != null) {
                var ab = z.dataContext;
                if (s == 1) {
                    if (aa >= 0 && aa < this.dp.count) {
                        if (q != null && q.i$b != null && q.i$b.count > aa) {
                            aa = q.i$b._inner[aa];
                        }
                        ab.item = this.dp.item(aa);
                    }
                }
                else {
                    ab.item = null;
                }
            }
            this.y7.ad(z, false, false, false, false);
            z.ap = this.y7.k;
            z.aq = this.y7.l;
            m.dz(z, v, Math.min(x, w));
        }
        m.du.count = t;
        b.dg(a);
    };
    Object.defineProperty(ColumnSeries.prototype, "ac5", {
        get: function () {
            return this.ac4;
        },
        set: function (a) {
            if (this.ac5 != a) {
                var b = this.ac5;
                this.ac4 = a;
                this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.ac5));
            }
        },
        enumerable: false,
        configurable: true
    });
    ColumnSeries.prototype.ac6 = function (a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.ac5) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                var b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                var c = this.yAxis.eo(b, new ScalerParams(1, this.dc.xc, this.dc.xb, this.yAxis.ch));
                if (c < this.yAxis.me) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                var d = (a[1] + a[2]) / 2;
                var e = this.yAxis.eo(d, new ScalerParams(1, this.dc.xc, this.dc.xb, this.yAxis.ch));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.me) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    };
    Object.defineProperty(ColumnSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zv;
        },
        enumerable: false,
        configurable: true
    });
    ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
    ColumnSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:ac7:add', [1, 0], 'RadiusY:ac8:ade', [1, 0]]);
    return ColumnSeries;
}(HorizontalAnchoredCategorySeries));
export { ColumnSeries };
/**
 * @hidden
 */
var ColumnSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnSeriesView, _super);
    function ColumnSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dt = null;
        _this.dv = null;
        _this.d0 = new Rectangle();
        _this.du = null;
        _this.dt = a;
        _this.du = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.d1);
            $ret.activate = runOn(_this, _this.dw);
            $ret.disactivate = runOn(_this, _this.dy);
            $ret.destroy = runOn(_this, _this.dx);
            return $ret;
        })());
        return _this;
    }
    ColumnSeriesView.prototype.a4 = function () {
        _super.prototype.a4.call(this);
        this.dv = new List$1(Rectangle.$, 0);
        if (!this.t) {
            this.dt.jq = Defaults.i;
            this.dt.xf = Defaults.c;
        }
    };
    ColumnSeriesView.prototype.d1 = function () {
        var a = new Rectangle();
        this.dv.add(a);
        a._visibility = 1;
        return a;
    };
    ColumnSeriesView.prototype.dw = function (a) {
        a._visibility = 0;
    };
    ColumnSeriesView.prototype.dy = function (a) {
        a._visibility = 1;
    };
    ColumnSeriesView.prototype.dx = function (a) {
        this.dv.remove(a);
    };
    ColumnSeriesView.prototype.dz = function (a, b, c) {
        if (!this.isDirty) {
            this.a2();
        }
        a.o = c;
        a.n = b;
    };
    ColumnSeriesView.prototype.ak = function (a) {
        return this.dv._inner[a];
    };
    ColumnSeriesView.prototype.aj = function (a) {
        var b = this.dv._inner[a];
        this.d0._visibility = b._visibility;
        this.d0.n = b.n;
        this.d0.o = b.o;
        this.d0.width = b.width;
        this.d0.height = b.height;
        var c = this.b4(a);
        this.d0._fill = c;
        this.d0._stroke = c;
        this.d0.ad = this.f.ig + 3;
        return this.d0;
    };
    ColumnSeriesView.prototype.bj = function (a, b) {
        _super.prototype.bj.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.dv.count; c++) {
                var d = this.ai(c, b);
                this.br(d, c, b);
                a.w(d);
            }
        }
    };
    ColumnSeriesView.prototype.ax = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.ax.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = __values(fromEnum(this.du.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = __values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                this.f.bc.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        b++;
    };
    ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
    return ColumnSeriesView;
}(AnchoredCategorySeriesView));
export { ColumnSeriesView };
